@@ -36,6 +36,7 @@ from .openocd.commands import openocd
 from .python.commands import python
 from .wifi.commands import _wifi
 from .serial_ports.commands import serial_ports
+from .webcam.commands import webcam
 from .util import check_version
 
 def _decode_environment():
@@ -93,6 +94,7 @@ cli.add_command(openocd)
 cli.add_command(python)
 cli.add_command(_wifi)
 cli.add_command(serial_ports)
+cli.add_command(webcam)
 
 def setup_context(ctx, debug, colorize, skip_auth):
     """
