@@ -352,26 +352,26 @@ class LagerSession(BaseUrlSession):
         url = 'gateway/{}/wifi/state'.format(quote(gateway))
         return self.get(url)
 
-    def get_wifi_access_points(self, gateway):
+    def get_wifi_access_points(self, gateway, interface):
         """
             Get access points visible to the specified gateway
         """
         url = 'gateway/{}/wifi/access-points'.format(quote(gateway))
-        return self.get(url)
+        return self.get(url, params={'interface': interface})
 
-    def connect_wifi(self, gateway, ssid, password):
+    def connect_wifi(self, gateway, ssid, password, interface):
         """
             Connect the gateway to a wifi network
         """
         url = 'gateway/{}/wifi/connect'.format(quote(gateway))
-        return self.post(url, json={'ssid': ssid, 'password': password})
+        return self.post(url, json={'ssid': ssid, 'password': password, 'iface': interface})
 
-    def delete_wifi_connection(self, gateway, ssid):
+    def delete_wifi_connection(self, gateway, ssid, interface):
         """
             Delete the wifi connection for the specified gateway
         """
         url = 'gateway/{}/wifi/delete-connection'.format(quote(gateway))
-        return self.post(url, json={'ssid': ssid})
+        return self.post(url, json={'ssid': ssid, 'iface': interface})
 
     def can_up(self, gateway, bitrate, interfaces):
         """
@@ -421,6 +421,19 @@ class LagerSession(BaseUrlSession):
         url = 'gateway/{}/adc/read'.format(quote(gateway))
         return self.post(url, json=data)
 
+    def reboot_gateway(self, gateway):
+        """
+            Reboot gateway
+        """
+        url = 'gateway/{}/reboot'.format(quote(gateway))
+        return self.post(url)
+
+    def shutdown_gateway(self, gateway):
+        """
+            shutdown gateway
+        """
+        url = 'gateway/{}/poweroff'.format(quote(gateway))
+        return self.post(url)
 
 class LagerContext:  # pylint: disable=too-few-public-methods
     """
@@ -460,6 +473,10 @@ class LagerContext:  # pylint: disable=too-few-public-methods
             path = f'/ws/gateway/{kwargs["gateway_id"]}/gdb-tunnel/3333'
         elif socktype == 'openocd-tunnel':
             path = f'/ws/gateway/{kwargs["gateway_id"]}/gdb-tunnel/4444'
+        elif socktype == 'webcam-tunnel':
+            path = f'/ws/gateway/{kwargs["gateway_id"]}/gdb-tunnel/8081'
+        elif socktype == 'pdb':
+            path = f'/ws/gateway/{kwargs["gateway_id"]}/gdb-tunnel/5555'
         else:
             raise ValueError(f'Invalid websocket type: {socktype}')
         uri = urllib.parse.urljoin(self.ws_host, path)
