@@ -45,7 +45,7 @@ async def cloud_connection_handler(connection_params, gdb_client_stream):
     """
     (uri, kwargs) = connection_params
     sockname = gdb_client_stream.socket.getsockname()
-    click.echo(f'Serving gdb client: {sockname}')
+    click.echo(f'Serving client: {sockname}')
     try:
         async with trio_websocket.open_websocket_url(uri, disconnect_timeout=1, **kwargs) as websocket:
             async with trio.open_nursery() as nursery:
@@ -55,7 +55,7 @@ async def cloud_connection_handler(connection_params, gdb_client_stream):
     except Exception as exc:  # pylint: disable=broad-except
         logger.exception('Exception in connection_handler', exc_info=exc)
     finally:
-        click.echo(f'gdb client disconnected: {sockname}')
+        click.echo(f'client disconnected: {sockname}')
 
 async def send_to_local_client(gateway_stream, gdb_client_stream, nursery):
     try:
@@ -92,7 +92,7 @@ async def local_connection_handler(session, gateway, remote_host, remote_port, g
         # resp = session.start_local_gdb_tunnel(gateway, False).json()
         remote_host = resp['host']
         remote_port = int(resp['port'])
-    click.echo(f'Serving gdb client: {sockname}')
+    click.echo(f'Serving client: {sockname}')
     try:
         async with await trio.open_tcp_stream(remote_host, remote_port) as gateway_stream:
             async with trio.open_nursery() as nursery:
@@ -103,7 +103,7 @@ async def local_connection_handler(session, gateway, remote_host, remote_port, g
     except Exception as exc:  # pylint: disable=broad-except
         logger.exception('Exception in connection_handler', exc_info=exc)
     finally:
-        click.echo(f'gdb client disconnected: {sockname}')
+        click.echo(f'client disconnected: {sockname}')
 
 async def serve_tunnel(host, port, connection_params, name, *, task_status=trio.TASK_STATUS_IGNORED):
     """
@@ -115,7 +115,8 @@ async def serve_tunnel(host, port, connection_params, name, *, task_status=trio.
 
         server = await nursery.start(serve_listeners)
         task_status.started(server)
-        click.echo(f'Serving {name} on {host}:{port}. Press Ctrl+C to quit.')
+        if name:
+            click.echo(f'Serving {name} on {host}:{port}. Press Ctrl+C to quit.')
         try:
             await trio.sleep_forever()
         except KeyboardInterrupt:
