@@ -1,14 +1,17 @@
 """
-    lager.flash.commands
+    lager.python.commands
 
-    Commands for flashing a DUT
+    Commands for running lager python
 """
 import os
 import sys
+import threading
 import itertools
 import functools
 import signal
 import click
+import trio
+from ..gdbserver.tunnel import serve_tunnel
 from ..context import get_default_gateway
 from ..util import (
     stream_python_output, zip_dir, SizeLimitExceeded,
@@ -43,11 +46,42 @@ def _do_exit(exit_code):
         click.secho('Gateway script forcibly killed due to timeout.', fg='red', err=True)
     sys.exit(exit_code)
 
+def debug_tunnel(ctx, gateway):
+    host = 'localhost'
+    port = 5555
+    connection_params = ctx.obj.websocket_connection_params(socktype='pdb', gateway_id=gateway)
+    try:
+        trio.run(serve_tunnel, host, port, connection_params, None)
+    except PermissionError as exc:
+        click.secho(str(exc), fg='red', err=True)
+        if ctx.obj.debug:
+            raise
+    except OSError as exc:
+        click.secho(f'Could not start remote pdb on port {port}: {exc}', fg='red', err=True)
+        if ctx.obj.debug:
+            raise
+
+_SIGNAL_MAP = {
+    'SIGINT': 2,
+    'SIGQUIT': 3,
+    'SIGABRT': 6,
+    'SIGKILL': 9,
+    'SIGUSR1': 10,
+    'SIGUSR2': 12,
+    'SIGTERM': 15,
+    'SIGSTOP': 19,
+}
+
+_SIGNAL_CHOICES = click.Choice(list(_SIGNAL_MAP.keys()), case_sensitive=False)
+
+def _get_signal_number(name):
+    return _SIGNAL_MAP[name.upper()]
+
 @click.command()
 @click.pass_context
 @click.argument('runnable', required=False, type=click.Path(exists=True))
 @click.option('--gateway', required=False, help='ID of gateway to which DUT is connected')
-@click.option('--image', default='lagerdata/gatewaypy3:v0.1.61', help='Docker image to use for running script')
+@click.option('--image', default='lagerdata/gatewaypy3:v0.1.68', help='Docker image to use for running script')
 @click.option(
     '--env',
     multiple=True, type=EnvVarType(), help='Environment variables to set for the python script. '
@@ -59,7 +93,7 @@ def _do_exit(exit_code):
     'command line. Example: `--passenv FOO` will set an environment variable named `FOO` in the python script to the value'
     'of `FOO` in the current environment.')
 @click.option('--kill', is_flag=True, default=False, help='Terminate a running python script')
-@click.option('--signal', 'signum', type=click.INT, default=signal.SIGTERM, help='Signal to use with --kill', show_default=True)
+@click.option('--signal', 'signum', default='SIGTERM', type=_SIGNAL_CHOICES, help='Signal to use with --kill', show_default=True)
 @click.option('--timeout', type=click.INT, required=False, help='Max runtime in seconds for the python script')
 @click.option('--detach', '-d', is_flag=True, required=False, default=False, help='Detach')
 @click.argument('args', nargs=-1)
@@ -75,10 +109,14 @@ def python(ctx, runnable, gateway, image, env, passenv, kill, signum, timeout, d
         gateway = get_default_gateway(ctx)
 
     if kill:
+        signum = _get_signal_number(signum)
         resp = session.kill_python(gateway, signum)
         resp.raise_for_status()
         return
 
+    thread = threading.Thread(target=debug_tunnel, args=(ctx, gateway), daemon=True)
+    thread.start()
+
     post_data = [
         ('image', image),
         ('stdout_is_stderr', stdout_is_stderr()),
