@@ -38,15 +38,18 @@ def status(ctx, gateway):
 @_wifi.command()
 @click.pass_context
 @click.option('--gateway', required=False, help='ID of gateway')
-def access_points(ctx, gateway):
+@click.option('--interface', required=False, help='Wireless interface to use')
+def access_points(ctx, gateway, interface=None):
     """
         Get WiFi access points visible to the gateway
     """
+    # TODO implement table for ext wifi
+
     if gateway is None:
         gateway = get_default_gateway(ctx)
 
     session = ctx.obj.session
-    resp = session.get_wifi_access_points(gateway)
+    resp = session.get_wifi_access_points(gateway, interface)
     resp.raise_for_status()
 
     table = Texttable()
@@ -59,12 +62,14 @@ def access_points(ctx, gateway):
 
     click.echo(table.draw())
 
+
 @_wifi.command()
 @click.pass_context
 @click.option('--gateway', required=False, help='ID of gateway')
 @click.option('--ssid', required=True, help='SSID of the network to connect to')
 @click.option('--password', required=False, help='Password of the network to connect to', default='')
-def connect(ctx, gateway, ssid, password=''):
+@click.option('--interface', required=False, help='Wireless interface to use')
+def connect(ctx, gateway, ssid, password='', interface=None):
     """
         Connect the gateway to a new network
     """
@@ -72,7 +77,7 @@ def connect(ctx, gateway, ssid, password=''):
         gateway = get_default_gateway(ctx)
 
     session = ctx.obj.session
-    resp = session.connect_wifi(gateway, ssid, password)
+    resp = session.connect_wifi(gateway, ssid, password, interface)
     resp.raise_for_status()
     if resp.json().get('acknowledged'):
         click.echo('Acknowledged', nl=False)
@@ -81,8 +86,9 @@ def connect(ctx, gateway, ssid, password=''):
 @_wifi.command()
 @click.pass_context
 @click.option('--gateway', required=False, help='ID of gateway')
-@click.option('--ssid', required=True, help='SSID of the network to delete')
-def delete_connection(ctx, gateway, ssid):
+@click.option('--ssid', required=False, help='SSID of the network to delete')
+@click.option('--interface', required=False, help='Wireless interface to use')
+def delete_connection(ctx, gateway, ssid=None, interface=None):
     """
         Delete the specified network from the gateway
     """
@@ -90,7 +96,7 @@ def delete_connection(ctx, gateway, ssid):
         gateway = get_default_gateway(ctx)
 
     session = ctx.obj.session
-    resp = session.delete_wifi_connection(gateway, ssid)
+    resp = session.delete_wifi_connection(gateway, ssid, interface)
     resp.raise_for_status()
     if resp.json().get('acknowledged'):
         click.echo('Acknowledged', nl=False)
